<#--
/*******************************************************************************
Copyright (c) 2013-2014 released Microchip Technology Inc.  All rights reserved.

Microchip licenses to you the right to use, modify, copy and distribute
Software only when embedded on a Microchip microcontroller or digital signal
controller that is integrated into your product or third party product
(pursuant to the sublicense terms in the accompanying license agreement).

You should refer to the license agreement accompanying this Software for
additional information regarding your rights and obligations.

SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND,
EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF
MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
IN NO EVENT SHALL MICROCHIP OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER
CONTRACT, NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR
OTHER LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR
CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT OF
SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
(INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.
 *******************************************************************************/
 -->
<#macro SYS_CLK_PERIPHERAL_CLK_ENABLE_INSTANCE SYS_CLK_PBCLKX SYS_CLK_PBDIV SYS_CLK_PBCLKNUM>
    /* Enable Peripheral Bus ${SYS_CLK_PBCLKNUM} */
    PLIB_OSC_PBClockDivisorSet (OSC_ID_0, ${SYS_CLK_PBCLKX}, ${SYS_CLK_PBDIV} );
<#if CONFIG_PIC32MZ == true>    
    PLIB_OSC_PBOutputClockEnable (OSC_ID_0, ${SYS_CLK_PBCLKX} );
</#if>
</#macro>
<#macro SYS_CLK_PERIPHERAL_CLK_DISABLE_INSTANCE SYS_CLK_PBCLKX SYS_CLK_PBCLKNUM></#macro>
<#macro SYS_CLK_REFCLK_ENABLE_INSTANCE SYS_CLK_REFCLKX SYS_CLK_REFCLK_SOURCE SYS_CLK_REFCLKNUM 
SYS_CLK_REFCLK_ROSEL SYS_CLK_REFCLK_RODIV SYS_CLK_REFCLK_ROTRIM>
    /* Enable and configure REFCLKO${SYS_CLK_REFCLKNUM}*/
    
    /* ROSEL ${SYS_CLK_REFCLK_SOURCE} */
    PLIB_OSC_ReferenceOscBaseClockSelect ( OSC_ID_0, ${SYS_CLK_REFCLKX}, ${SYS_CLK_REFCLK_ROSEL} );
    /* RODIV */
    PLIB_OSC_ReferenceOscDivisorValueSet ( OSC_ID_0, ${SYS_CLK_REFCLKX}, ${SYS_CLK_REFCLK_RODIV} );
    /* ROTRIM */
    PLIB_OSC_ReferenceOscTrimSet ( OSC_ID_0, ${SYS_CLK_REFCLKX}, ${SYS_CLK_REFCLK_ROTRIM} );

    PLIB_OSC_ReferenceOscEnable ( OSC_ID_0, ${SYS_CLK_REFCLKX} );</#macro>
<#macro SYS_CLK_REFCLK_DISABLE_INSTANCE SYS_CLK_REFCLKX SYS_CLK_REFCLKNUM>
    /* Disable REFCLKO${SYS_CLK_REFCLKNUM}*/
    PLIB_OSC_ReferenceOscDisable ( OSC_ID_0, ${SYS_CLK_REFCLKX} );</#macro>
<#macro SYS_CLK_REFCLK_OUTPUT_ENABLE_INSTANCE SYS_CLK_REFCLKX SYS_CLK_REFCLKNUM>
    /* Disable REFCLK${SYS_CLK_REFCLKNUM}_OE*/
    PLIB_OSC_ReferenceOutputEnable ( OSC_ID_0, ${SYS_CLK_REFCLKX} );</#macro>
<#macro SYS_CLK_REFCLK_OUTPUT_DISABLE_INSTANCE SYS_CLK_REFCLKX SYS_CLK_REFCLKNUM>
    /* Disable REFCLK${SYS_CLK_REFCLKNUM}_OE*/
    PLIB_OSC_ReferenceOutputDisable ( OSC_ID_0, ${SYS_CLK_REFCLKX} );</#macro>

/*******************************************************************************
  Function:
    void SYS_CLK_DYNAMIC_Initialize ( void )

  Summary:
    Initializes the peripheral bus clock dividers, reference clock dividers and output enables

 */

void SYS_CLK_DYNAMIC_Initialize()
{
    SYS_DEVCON_SystemUnlock ( );

    /* System Clock Initialization Code */
    PLIB_OSC_FRCDivisorSelect( OSC_ID_0, ${CONFIG_SYS_CLK_FRCDIV});

<#if CONFIG_PIC32MX == true && CONFIG_SYS_CLK_CONFIG_UFRCEN == "ON">
    /* Enable Secondary Oscillator */
    PLIB_OSC_UsbClockSourceSelect( OSC_ID_0 , SYS_OSC_USBCLK_FRC );

<#elseif CONFIG_PIC32MX == true && CONFIG_SYS_CLK_CONFIG_UFRCEN == "OFF">
    /* Disable Secondary Oscillator */
    PLIB_OSC_UsbClockSourceSelect( OSC_ID_0 , SYS_OSC_USBCLK_PRIMARY );

</#if>
<#if CONFIG_SYS_CLK_CONFIG_SOSCEN == "ON">
    /* Enable Secondary Oscillator */
    PLIB_OSC_SecondaryEnable( OSC_ID_0 );

<#elseif CONFIG_SYS_CLK_CONFIG_SOSCEN == "OFF">
    /* Disable Secondary Oscillator */
    PLIB_OSC_SecondaryDisable( OSC_ID_0 );

</#if>
<#if CONFIG_SYS_CLK_PBCLK0_ENABLE == true>
<@SYS_CLK_PERIPHERAL_CLK_ENABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_1" SYS_CLK_PBCLKNUM="1" SYS_CLK_PBDIV=CONFIG_SYS_CLK_PBDIV0 />
</#if>
<#if CONFIG_PIC32MZ == true>    
<#if CONFIG_SYS_CLK_PBCLK1_ENABLE == true>
<@SYS_CLK_PERIPHERAL_CLK_ENABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_2" SYS_CLK_PBCLKNUM="2" SYS_CLK_PBDIV=CONFIG_SYS_CLK_PBDIV1 />
<#else>
<@SYS_CLK_PERIPHERAL_CLK_DISABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_2" SYS_CLK_PBCLKNUM="2" />
</#if>
<#if CONFIG_SYS_CLK_PBCLK2_ENABLE == true>
<@SYS_CLK_PERIPHERAL_CLK_ENABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_3" SYS_CLK_PBCLKNUM="3" SYS_CLK_PBDIV=CONFIG_SYS_CLK_PBDIV2 />
<#else>
<@SYS_CLK_PERIPHERAL_CLK_DISABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_3" SYS_CLK_PBCLKNUM="3" />
</#if>
<#if CONFIG_SYS_CLK_PBCLK3_ENABLE == true>
<@SYS_CLK_PERIPHERAL_CLK_ENABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_4" SYS_CLK_PBCLKNUM="4" SYS_CLK_PBDIV=CONFIG_SYS_CLK_PBDIV3 />
<#else>
<@SYS_CLK_PERIPHERAL_CLK_DISABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_4" SYS_CLK_PBCLKNUM="4" />
</#if>
<#if CONFIG_SYS_CLK_PBCLK4_ENABLE == true>
<@SYS_CLK_PERIPHERAL_CLK_ENABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_5" SYS_CLK_PBCLKNUM="5" SYS_CLK_PBDIV=CONFIG_SYS_CLK_PBDIV4 />
<#else>
<@SYS_CLK_PERIPHERAL_CLK_DISABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_5" SYS_CLK_PBCLKNUM="5" />
</#if>
<#if CONFIG_SYS_CLK_PBCLK6_ENABLE == true>
<@SYS_CLK_PERIPHERAL_CLK_ENABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_7" SYS_CLK_PBCLKNUM="7" SYS_CLK_PBDIV=CONFIG_SYS_CLK_PBDIV6 />
<#else>
<@SYS_CLK_PERIPHERAL_CLK_DISABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_7"SYS_CLK_PBCLKNUM="7" />
</#if>
<#if CONFIG_SYS_CLK_PBCLK7_ENABLE == true>
<@SYS_CLK_PERIPHERAL_CLK_ENABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_8" SYS_CLK_PBCLKNUM="8" SYS_CLK_PBDIV=CONFIG_SYS_CLK_PBDIV7 />
<#else>
<@SYS_CLK_PERIPHERAL_CLK_DISABLE_INSTANCE SYS_CLK_PBCLKX="OSC_PERIPHERAL_BUS_8" SYS_CLK_PBCLKNUM="8" />
</#if>    
</#if>    
<#if CONFIG_HAVE_REFCLOCK == true>    
<#if CONFIG_PIC32MX == true>    
<#if CONFIG_SYS_CLK_REFCLK_ENABLE == true>
<@SYS_CLK_REFCLK_ENABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_1" SYS_CLK_REFCLKNUM="1" 
SYS_CLK_REFCLK_RODIV=CONFIG_SYS_CLK_RODIV
SYS_CLK_REFCLK_SOURCE=CONFIG_SYS_CLK_REFCLK_SOURCE SYS_CLK_REFCLK_ROTRIM=CONFIG_SYS_CLK_ROTRIM
SYS_CLK_REFCLK_ROSEL=CONFIG_SYS_CLK_REFCLK_ROSEL/>
<#else>
<@SYS_CLK_REFCLK_DISABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_1" SYS_CLK_REFCLKNUM="1" />
</#if>
<#if CONFIG_SYS_CLK_REFCLK_OE == true>
<@SYS_CLK_REFCLK_OUTPUT_ENABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_1" SYS_CLK_REFCLKNUM="1" />
<#else>
<@SYS_CLK_REFCLK_OUTPUT_DISABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_1" SYS_CLK_REFCLKNUM="1" />
</#if></#if>
<#if CONFIG_PIC32MZ == true>    
<#if CONFIG_SYS_CLK_REFCLK0_ENABLE == true>
<@SYS_CLK_REFCLK_ENABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_1" SYS_CLK_REFCLKNUM="1" 
SYS_CLK_REFCLK_RODIV=CONFIG_SYS_CLK_RODIV0
SYS_CLK_REFCLK_SOURCE=CONFIG_SYS_CLK_REFCLK_SOURCE0 SYS_CLK_REFCLK_ROTRIM=CONFIG_SYS_CLK_ROTRIM0
SYS_CLK_REFCLK_ROSEL=CONFIG_SYS_CLK_REFCLK_ROSEL0/>
<#else>
<@SYS_CLK_REFCLK_DISABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_1" SYS_CLK_REFCLKNUM="1" />
</#if>
<#if CONFIG_SYS_CLK_REFCLK0_OE == true>
<@SYS_CLK_REFCLK_OUTPUT_ENABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_1" SYS_CLK_REFCLKNUM="1" />
<#else>
<@SYS_CLK_REFCLK_OUTPUT_DISABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_1" SYS_CLK_REFCLKNUM="1" />
</#if>
<#if CONFIG_SYS_CLK_REFCLK1_ENABLE == true>
<@SYS_CLK_REFCLK_ENABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_2" SYS_CLK_REFCLKNUM="2" 
SYS_CLK_REFCLK_RODIV=CONFIG_SYS_CLK_RODIV1
SYS_CLK_REFCLK_SOURCE=CONFIG_SYS_CLK_REFCLK_SOURCE1 SYS_CLK_REFCLK_ROTRIM=CONFIG_SYS_CLK_ROTRIM1
SYS_CLK_REFCLK_ROSEL=CONFIG_SYS_CLK_REFCLK_ROSEL1/>
<#else>
<@SYS_CLK_REFCLK_DISABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_2" SYS_CLK_REFCLKNUM="2" />
</#if>
<#if CONFIG_SYS_CLK_REFCLK1_OE == true>
<@SYS_CLK_REFCLK_OUTPUT_ENABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_2" SYS_CLK_REFCLKNUM="2" />
<#else>
<@SYS_CLK_REFCLK_OUTPUT_DISABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_2" SYS_CLK_REFCLKNUM="2" />
</#if>
<#if CONFIG_SYS_CLK_REFCLK2_ENABLE == true>
<@SYS_CLK_REFCLK_ENABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_3" SYS_CLK_REFCLKNUM="3" 
SYS_CLK_REFCLK_RODIV=CONFIG_SYS_CLK_RODIV2
SYS_CLK_REFCLK_SOURCE=CONFIG_SYS_CLK_REFCLK_SOURCE2 SYS_CLK_REFCLK_ROTRIM=CONFIG_SYS_CLK_ROTRIM2
SYS_CLK_REFCLK_ROSEL=CONFIG_SYS_CLK_REFCLK_ROSEL2/>
<#else>
<@SYS_CLK_REFCLK_DISABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_3" SYS_CLK_REFCLKNUM="3" />
</#if>
<#if CONFIG_SYS_CLK_REFCLK2_OE == true>
<@SYS_CLK_REFCLK_OUTPUT_ENABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_3" SYS_CLK_REFCLKNUM="3" />
<#else>
<@SYS_CLK_REFCLK_OUTPUT_DISABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_3" SYS_CLK_REFCLKNUM="3" />
</#if>
<#if CONFIG_SYS_CLK_REFCLK3_ENABLE == true>
<@SYS_CLK_REFCLK_ENABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_4" SYS_CLK_REFCLKNUM="4" 
SYS_CLK_REFCLK_RODIV=CONFIG_SYS_CLK_RODIV3
SYS_CLK_REFCLK_SOURCE=CONFIG_SYS_CLK_REFCLK_SOURCE3 SYS_CLK_REFCLK_ROTRIM=CONFIG_SYS_CLK_ROTRIM3
SYS_CLK_REFCLK_ROSEL=CONFIG_SYS_CLK_REFCLK_ROSEL3/>
<#else>
<@SYS_CLK_REFCLK_DISABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_4" SYS_CLK_REFCLKNUM="4" />
</#if>
<#if CONFIG_SYS_CLK_REFCLK3_OE == true>
<@SYS_CLK_REFCLK_OUTPUT_ENABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_4" SYS_CLK_REFCLKNUM="4" />
<#else>
<@SYS_CLK_REFCLK_OUTPUT_DISABLE_INSTANCE SYS_CLK_REFCLKX="OSC_REFERENCE_4" SYS_CLK_REFCLKNUM="4" />
</#if>
</#if></#if>

    SYS_DEVCON_SystemLock ( );
}

<#--
/*******************************************************************************
 End of File
*/
-->
